#
# spec file for package python-textdistance
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-textdistance
Version:        4.6.1
Release:        1.3
Summary:        Compute distance between the two texts
License:        MIT
URL:            https://github.com/life4/textdistance
Source:         https://github.com/life4/textdistance/archive/refs/tags/%{version}.tar.gz#/textdistance-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE hypothesis-profile-conftest.patch -- add hypothesis profile for slow OBS executions, code@bnavigator.de
Patch1:         hypothesis-profile-conftest.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-distance
Recommends:     python-jellyfish
Recommends:     python-numpy
Recommends:     python-python-Levenshtein
Recommends:     python-pyxDamerauLevenshtein
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Compute distance between sequences. 30+ algorithms, pure python
implementation, common interface, optional external libs usage.

%prep
%autosetup -p1 -n textdistance-%{version}
chmod a-x README.md

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# we don't have all external libraries to test with
%pytest -m "not external" --hypothesis-profile obs

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/textdistance
%{python_sitelib}/textdistance-%{version}*-info

%changelog
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 4.6.1:
  * Remove abydos references from libraries.json
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 4.6.0:
  * Drop abydos
  * Remove executable bit from filesystem permissions of
    README.md
  * Replace deprecated license_file with license_files in
    setup.cfg
* Wed Feb  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.5.0:
  * Run Python 3.10 tests on CI
  * Type annotations
  * Add new DamerauLevenshtein... classes
  * update rapidfuzz
  * Ensure that maximum normalised distance is <= 1
  * Ensure editex parameters are sensible
  * Ignore inconsistent timings on some comparison tests
  * add support for rapidfuzz
- Fix up the download URL due to upstream dropping v.
* Sat Jun 18 2022 Ben Greiner <code@bnavigator.de>
- More than one test can timeout
  * Drop extend-timeout.patch
  * Add hypothesis-profile-conftest.patch
* Tue Mar  1 2022 pgajdos@suse.com
- version update to 4.2.1
  * no upstream changelog
* Thu Feb 18 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build (no numpy)
* Sun Jan  3 2021 Matej Cepl <mcepl@suse.com>
- Add extend-timeout.patch switching off timeout on failing test.
* Sat Dec 19 2020 Benjamin Greiner <code@bnavigator.de>
- Initial specfile for version 4.2.0
- required by spyder 4.2.1
